@@ -47,21 +47,23 @@ from pathlib import Path
 from . import run, __version__
 from .json_serializer import PatternInfoSerializer
 
-docopt_schema = Schema({
-    '--path': Use(str),
-    '--cu-xml': Use(str),
-    '--dep-file': Use(str),
-    '--loop-counter': Use(str),
-    '--reduction': Use(str),
-    '--fmap': Use(str),
-    '--plugins': Use(str),
-    '--json': Use(str),
-    '--task-pattern': Use(bool),
-    '--cu-inst-res': Use(str),
-    '--llvm-cxxfilt-path': Use(str),
-    '--dp-build-path': Use(str),
-    '--generate-data-cu-inst': Use(str),
-})
+docopt_schema = Schema(
+    {
+        "--path": Use(str),
+        "--cu-xml": Use(str),
+        "--dep-file": Use(str),
+        "--loop-counter": Use(str),
+        "--reduction": Use(str),
+        "--fmap": Use(str),
+        "--plugins": Use(str),
+        "--json": Use(str),
+        "--task-pattern": Use(bool),
+        "--cu-inst-res": Use(str),
+        "--llvm-cxxfilt-path": Use(str),
+        "--dp-build-path": Use(str),
+        "--generate-data-cu-inst": Use(str),
+    }
+)
 
 
 def get_path(base_path: str, file_name: str) -> str:
@@ -75,7 +77,6 @@ def get_path(base_path: str, file_name: str) -> str:
 
 
 def main():
-    # t1 = time.time()
     arguments = docopt(__doc__, version=f"DiscoPoP Version {__version__}")
 
     try:
@@ -83,16 +84,16 @@ def main():
     except SchemaError as e:
         exit(e)
 
-    path = arguments['--path']
+    path = arguments["--path"]
 
-    cu_xml = get_path(path, arguments['--cu-xml'])
-    dep_file = get_path(path, arguments['--dep-file'])
-    loop_counter_file = get_path(path, arguments['--loop-counter'])
-    reduction_file = get_path(path, arguments['--reduction'])
-    file_mapping = get_path(path, 'FileMapping.txt')
-    cu_inst_result_file = get_path(path, arguments['--cu-inst-res'])
-    if arguments['--dp-build-path'] != 'None':
-        discopop_build_path = arguments['--dp-build-path']
+    cu_xml = get_path(path, arguments["--cu-xml"])
+    dep_file = get_path(path, arguments["--dep-file"])
+    loop_counter_file = get_path(path, arguments["--loop-counter"])
+    reduction_file = get_path(path, arguments["--reduction"])
+    file_mapping = get_path(path, "FileMapping.txt")
+    cu_inst_result_file = get_path(path, arguments["--cu-inst-res"])
+    if arguments["--dp-build-path"] != "None":
+        discopop_build_path = arguments["--dp-build-path"]
     else:
         # set default discopop build path
         discopop_build_path = Path(__file__).resolve().parent.parent
@@ -100,32 +101,46 @@ def main():
 
     for file in [cu_xml, dep_file, loop_counter_file, reduction_file, file_mapping]:
         if not os.path.isfile(file):
-            print(f"File not found: \"{file}\"")
+            print(f'File not found: "{file}"')
             sys.exit()
 
-    plugins = [
-    ] if arguments['--plugins'] == 'None' else arguments['--plugins'].split(' ')
+    plugins = [] if arguments["--plugins"] == "None" else arguments["--plugins"].split(" ")
 
-    if arguments['--generate-data-cu-inst'] != 'None':
+    if arguments["--generate-data-cu-inst"] != "None":
         # start generation of Data_CUInst and stop execution afterwards
         from .generate_Data_CUInst import wrapper as generate_data_cuinst_wrapper
-        generate_data_cuinst_wrapper(cu_xml, dep_file, loop_counter_file, reduction_file,
-                                     arguments['--generate-data-cu-inst'])
+
+        generate_data_cuinst_wrapper(
+            cu_xml,
+            dep_file,
+            loop_counter_file,
+            reduction_file,
+            arguments["--generate-data-cu-inst"],
+        )
         sys.exit(0)
 
     start = time.time()
 
-    res = run(cu_xml, dep_file, loop_counter_file, reduction_file, plugins, file_mapping=file_mapping,
-              cu_inst_result_file=cu_inst_result_file, llvm_cxxfilt_path=arguments[
-                  '--llvm-cxxfilt-path'],
-              discopop_build_path=discopop_build_path, enable_task_pattern=arguments['--task-pattern'])
+    res = run(
+        cu_xml,
+        dep_file,
+        loop_counter_file,
+        reduction_file,
+        plugins,
+        file_mapping=file_mapping,
+        cu_inst_result_file=cu_inst_result_file,
+        llvm_cxxfilt_path=arguments["--llvm-cxxfilt-path"],
+        discopop_build_path=discopop_build_path,
+        enable_task_pattern=arguments["--task-pattern"],
+    )
 
     end = time.time()
 
-    if arguments['--json'] == 'None':
+    if arguments["--json"] == "None":
         print(str(res))
     else:
-        with open(arguments['--json'], 'w') as f:
+        print(str(res))
+        with open(arguments["--json"], "w") as f:
             json.dump(res, f, indent=2, cls=PatternInfoSerializer)
 
     print("Time taken for pattern detection: {0}".format(end - start))
